@@ -352,7 +352,7 @@ class WEngine:
         while True:
             time.sleep(1)
 
-    def get_wserver_id(self, table_name, wdb_id):
+    def get_wserver_id(self, table_name, wdb_id, *args, **kwargs):
         """
         Извлечь wserver_id записи по его id.
 
